<!doctype html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- CSRF Token -->
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">

    <title><?php echo e(config('app.name', 'Laravel')); ?></title>

    <!-- Scripts -->
    <script src="<?php echo e(asset('js/app.js')); ?>" defer></script>
    <script src="<?php echo e(asset('js/funciones.js')); ?>" defer></script>

    <!-- Fonts -->
    <link rel="dns-prefetch" href="//fonts.gstatic.com">
    <link href="https://fonts.googleapis.com/css?family=Nunito" rel="stylesheet">
    
    
    <!-- Styles -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@48,400,0,0" />
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link href="<?php echo e(asset('css/system.css')); ?>" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.2.1.slim.min.js" integrity="sha384-KJ3o2DKtIkvYIK3UENzmM7KCkRr/rE9/Qpg6aAZGJwFDMVNA/GpGFF93hXpG5KkN" crossorigin="anonymous"></script>
<script src="//ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>


<style>
    .nav-pills li {
    /*border: 1px solid #000; /* Cambia el color y el grosor del borde según tus preferencias */
    border-radius: 5px; /* 5 Añade esquinas redondeadas si lo deseas */
    margin: 0px; /*  5Agrega espacio entre los elementos */
    padding: 0px; /* 5 Agrega espacio interno para que el borde no toque el contenido */
}
.contornearmenu {
    border: 1px solid #000; /* Cambia el color y el grosor del borde según tus preferencias */
    border-radius: 5px; /* Añade esquinas redondeadas si lo deseas */
    margin: 5px; /* Agrega espacio entre los elementos */
    padding: 10px; /* Agrega espacio interno para que el borde no toque el contenido */
}
.menu-item-wrapper {
        display: flex;
        align-items: center; /* Esto alinea verticalmente los elementos dentro del contenedor */
        color: #000;
    }
</style>

</head>


<body>
    <div id="app">


     


        
        <div class="container-fluid">
            <div class="row">
                
                <div class="col-sm-auto bg-light sticky-top">
                    <div class="d-flex flex-sm-column flex-row flex-nowrap bg-light align-items-center sticky-top table-responsive">

                        <a href="/home" class="d-block p-3 link-dark text-decoration-none" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Icon-only">
                            
                            <img src="<?php echo e(asset('img/iconos/'.\App\Models\sucursales::getLogoHome())); ?>" alt="Logo" class="logo-logo-menu">
                        </a>

              
<?php
$url= $_SERVER["REQUEST_URI"];
$posicion_coincidencia = strpos($url, 'home');
if ($posicion_coincidencia === false) {
        $home = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_dashboard = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $home = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_dashboard = "style='margin-left: 35px;'";
}
/*****************************************************/
$posicion_coincidencia = strpos($url, 'clientes');
if ($posicion_coincidencia === false) {
    
        $clientes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_cliente = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
         
            $clientes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_cliente = "style='margin-left: 35px;'";
}
/*****************************************************/
/*****************************************************/
$posicion_coincidencia = strpos($url, 'ordendetrabajo');
if ($posicion_coincidencia === false) {
        $ordendetrabajo = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_orden = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $ordendetrabajo = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_orden = "style='margin-left: 35px;'";
}
/*****************************************************/
/*****************************************************/
$posicion_coincidencia = strpos($url, 'gohomei');
if ($posicion_coincidencia === false) {
        $informes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_informes = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $informes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_informes = "style='margin-left: 35px;'";
            $home = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_dashboard = "style='margin-left: 35px; opacity:0.5;'";
}
$agregar_gastos = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
/*****************************************************/
/*****************************************************/
$posicion_coincidencia = strpos($url, 'servicios');
if ($posicion_coincidencia === false) {
        $servicios = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_servicios = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $servicios = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_servicios = "style='margin-left: 35px;'";
}
/*****************************************************/
/*****************************************************/
$posicion_coincidencia = strpos($url, 'repuestos');
if ($posicion_coincidencia === false) {
        $repuestos = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_repuestos = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $repuestos = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_repuestos = "style='margin-left: 35px;'";
}
/*****************************************************/
/*****************************************************/
$posicion_coincidencia = strpos($url, 'usuarios');
if ($posicion_coincidencia === false) {
        $usuarios = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
            $padding_left_usuarios = "style='margin-left: 35px; opacity:0.5;'";
    }
    else{
            $usuarios = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
            $padding_left_usuarios = "style='margin-left: 35px;'";
}
/*****************************************************/

?>

                       
                        <ul class="nav nav-pills nav-flush flex-sm-column flex-row flex-nowrap mb-auto mx-auto text-center justify-content-between w-100 px-3 align-items-center">
                           

                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>
                            

                                    <li class="nav-item">
                                        

                                        <a href="/home" class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Home">
                                            <div class="menu-item-wrapper">
                                            <img src="<?php echo e(asset('img/iconos/dashboard.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_dashboard; ?>><?php echo $home; ?>
                                            </div>
                                            
                                            <b style="color: #fff;">Dashboard</b>
                                        </a>

                                    
                                    
                                </li>
                                    <li class="nav-item">
                                        <a href="<?php echo e(route('clientes')); ?>" class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Home">
                                        <div class="menu-item-wrapper">
                                        <img src="<?php echo e(asset('img/iconos/clientes512.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_cliente; ?>><?php echo $clientes; ?>
                                        </div>
                                        
                                        <b style="color: #fff;">Clientes</b>

                                        </a>
                                        
                                    </li>
                             
                            <?php endif; ?>  
                            
                            

                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria" || \App\Models\User::tipoUsuario() == "operario"): ?>
                            

                                <li>
                                    <a  href="<?php echo e(route('ordendetrabajo')); ?>"  class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Products">
                                    <div class="menu-item-wrapper">
                                    <img src="<?php echo e(asset('img/iconos/ot512.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_orden; ?>><?php echo $ordendetrabajo; ?>
                                    </div>
                                    
                                    <b style="color: #fff;">Ordenes trabajo</b>
                                    </a>
                                </li>

                            <?php endif; ?>  
                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria" ): ?>
                            

                            <li>
                                <?php
                                

                                $getDataUser = \App\Models\User::datosdelusaurioSeparados();
                                // echo $getDataUser[0]->nombre;
                                $nombre =base64_encode($getDataUser[0]->nombre);
                                $apellido = base64_encode($getDataUser[0]->apellido);
                                $nebio1 = base64_encode("nebio1"); 
                                $getSucursal =\App\Models\User::nameBranchId($getDataUser[0]->sucursales_id);
                                $sucursal = base64_encode($getSucursal);
                                ?>
                               
                                <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("agregargasto")])); ?>"  class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="" > 

                                <div class="menu-item-wrapper">
                                    <img src="<?php echo e(asset('img/iconos/gastos.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_informes; ?>><?php echo $agregar_gastos; ?>
                                </div>
                                <b style="color: #fff;">Agregar gasto</b>
                            </a>
                            </li>

                        <?php endif; ?>  

                        <li>
                                <a  href="<?php echo e(route('gohomeinformes')); ?> " class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Orders">

                                <div class="menu-item-wrapper">
                                    <img src="<?php echo e(asset('img/iconos/informe-pagos.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_informes; ?>><?php echo $informes; ?>
                                </div>
                                <b style="color: #fff;">Informes</b>
                            </a>
                        </li>




                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria" ): ?>

                            

                                    <?php endif; ?> 
                            


                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria" || \App\Models\User::tipoUsuario() == "operario"): ?>

                                    <li>
                                        <a  href="<?php echo e(route('servicios')); ?> " class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Orders">
                                        <div class="menu-item-wrapper">
                                        <img src="<?php echo e(asset('img/iconos/servicios512.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_servicios; ?>><?php echo $servicios; ?>
                                        </div>
                                        
                                        <b style="color: #fff;">Servicios</b>
                                        </a>
                                    </li>
                                    <li>
                                        <a  href="<?php echo e(route('repuestos')); ?> " class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Orders">
                                        <div class="menu-item-wrapper">
                                        <img src="<?php echo e(asset('img/iconos/repuesto_s.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_repuestos; ?>><?php echo $repuestos; ?>
                                        </div>
                                        
                                        <b style="color: #fff;">Repuestos</b>
                                        </a>
                                    </li>
                                 <?php endif; ?> 

                             
                                 <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" ): ?>
                                    

                                    <li>
                                        <a  href="<?php echo e(route('usuarios')); ?>" class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Dashboard">
                                        <div class="menu-item-wrapper">
                                        <img src="<?php echo e(asset('img/iconos/usuarios512.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_usuarios; ?>><?php echo $usuarios; ?>
                                        </div>
                                        
                                        <b style="color: #fff;">Usuarios</b>
                                        </a>
                                    </li>
                            <?php endif; ?>  


                        </ul>
                        <div class="dropdown">
                            <a href="#" class="d-flex align-items-center justify-content-center p-3 link-dark text-decoration-none dropdown-toggle" id="dropdownUser3" data-bs-toggle="dropdown" aria-expanded="false">
                                <span class="material-symbols-outlined">
                                    <span class="material-symbols-outlined">
exit_to_app
</span>
                                    </span>                            </a>
                            <ul class="dropdown-menu text-small shadow" aria-labelledby="dropdownUser3">
                                <li>
                                    <form action="<?php echo e(route('logout')); ?>" method="POST">
                                        <?php echo csrf_field(); ?>
                                        <button class="btn bt--danger" type="submit">Cerrar Sesión</button>
                                    </form>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="col-sm p-3 min-vh-100">
                    <div class="dropdown" style="text-align: right">
                        <button class="btn btn-secondary dropdown-toggle" type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown" aria-expanded="false">
                            
                             <span style="color:white" class="username"> Bienvenido : <?php echo e(\App\Models\User::datosdelusaurio()); ?> |</span>

                            
                          
                            <?php if(\App\Models\User::tipoUsuario() != "superadmin" && \App\Models\User::tipoUsuario() != "admin"): ?>
                            <span style="color:white" class="username"> Suc : <?php echo e(\App\Models\User::nameBranch()); ?> </span>
                        
                                 <?php endif; ?>
                        </button>
                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                          <li>
            
                              
                    <form action="<?php echo e(route('logout')); ?>" method="POST">
                        <?php echo csrf_field(); ?>
                        <button class="btn bt--danger" type="submit">Cerrar Sesión</button>
                    </form>
            
                          </li>
                          
                        </ul>
                      </div>
                    <main class="py-4">
                        
                        <?php echo $__env->yieldContent('content'); ?>
                    </main>
                    
                </div>
            </div>
        </div>
        

      
         
    </div>
</body>
<style>
    
</style>
</html>
<?php /**PATH /var/www/html/sistema/resources/views/layouts/sidebar.blade.php ENDPATH**/ ?>